@@ -2,7 +2,7 @@ _name_map_ = {
 "json_formatter": "json"
 }
 
-def json_formatter(data):
+def json_formatter(data, **kwargs):
     """Method returns parsing result in json format.
     """
     from json import dumps
