@@ -2,7 +2,7 @@ _name_map_ = {
 "pprint_formatter": "pprint"
 }
 
-def pprint_formatter(data):
+def pprint_formatter(data, **kwargs):
     """Method to pprint format results
     """
     from pprint import pformat
