@@ -1,4 +1,4 @@
-def raw(data):
+def raw(data, **kwargs):
     """Method returns parsing results as python list or dictionary.
     """
     return data
\ No newline at end of file
