@@ -6,6 +6,6 @@ def record(data, source, target="_use_source_"):
         if target == "_use_source_":
             target = source
         # record variable:
-        _ttp_["results_object"].vars.update({target: source_var_value})
+        _ttp_["vars"].update({target: source_var_value})
         _ttp_["global_vars"].update({target: source_var_value})
     return data, None
\ No newline at end of file
