@@ -5,8 +5,8 @@ _name_map_ = {
 def set_func(data, source, target="_use_source_", default="_no_default_value_"):
     # source - name of source variable to retrieve value
     # target - name of variable to save into
-    if source in _ttp_["results_object"].vars:
-        source_var_value = _ttp_["results_object"].vars[source]
+    if source in _ttp_["vars"]:
+        source_var_value = _ttp_["vars"][source]
     elif default != "_no_default_value_":
         source_var_value = default
     else:
