@@ -11,7 +11,7 @@ def sformat(data, string, add_field):
         data[add_field] = string.format(**data)
     except KeyError: # KeyError happens when not enough keys in **kwargs supplied to format method
         kwargs = _ttp_["global_vars"].copy()
-        kwargs.update(_ttp_["parser_object"].vars)
+        kwargs.update(_ttp_["vars"])
         kwargs.update(data)
         try:
             data[add_field] = string.format(**kwargs)
