@@ -20,6 +20,14 @@ def load_files(path, extensions=[], filters=[], read=False):
     # need to use path[:5000] cause if path is actually text of the template
     # and has length more then X symbols, os.path will choke with "path too long"
     # error, hence the safe-assumption that no os path exists longer then 5000 symbols
+            
+    # check if structured, non text, data given, return it as is if so
+    # to process within input macro/function
+    if not isinstance(path, str):
+        return [('structured_data', path,)]
+    elif _ttp_['python_major_version'] == 2:
+        if not isinstance(path, (unicode, str,)):
+            return [('structured_data', path,)]
 
     # check if path is a path to file:
     if os.path.isfile(path[:5000]):
@@ -61,12 +69,6 @@ def load_files(path, extensions=[], filters=[], read=False):
     elif _ttp_['python_major_version'] == 2:
         if isinstance(path, unicode):
             return [('text_data', path,)]   
-    # check if path is a file object:
-    elif hasattr(path, 'read') and hasattr(path, 'name'):
-        if read:
-            return [('text_data', path.read(),)]
-        else:
-            return [('file_name', path.name(),)]
     else:
         return []
         
@@ -102,6 +104,12 @@ def load_struct(text_data="", **kwargs):
 def load_text(text_data, include=None, **kwargs):
     return text_data
     
+def _get_include_data(text_data, include):
+    files = load_files(path=include, extensions=[], filters=[], read=True)
+    for datum in files:
+        text_data += "\n" + datum[1]    
+    return text_data
+    
 def load_ini(text_data, include=None, **kwargs):
     if _ttp_["python_major_version"] is 3:
         import configparser
@@ -155,9 +163,7 @@ def load_ini(text_data, include=None, **kwargs):
 def load_python(text_data, include=None, **kwargs):
     data = {}
     if include:
-        files = load_files(path=include, extensions=[], filters=[], read=True)
-        for datum in files:
-            text_data += "\n" + datum[1]
+        text_data = _get_include_data(text_data, include)
     try:
         data = _ttp_["utils"]["load_python_exec"](text_data)
         return data
@@ -171,9 +177,7 @@ def load_yaml(text_data, include=None, **kwargs):
         log.error("loaders.load_yaml: failed to import yaml module, install: 'python -m pip install pyyaml'")
     data = {}
     if include:
-        files = load_files(path=include, extensions=[], filters=[], read=True)
-        for datum in files:
-            text_data += "\n" + datum[1]
+        text_data = _get_include_data(text_data, include)
     try:
         data = safe_load(text_data)
     except:
@@ -184,9 +188,7 @@ def load_json(text_data, include=None, **kwargs):
     from json import loads
     data = {}
     if include:
-        files = load_files(path=include, extensions=[], filters=[], read=True)
-        for datum in files:
-            text_data += "\n" + datum[1]
+        text_data = _get_include_data(text_data, include)
     try:
         data = loads(text_data)
         return data
@@ -201,6 +203,8 @@ def load_csv(text_data, include=None, **kwargs):
     key = kwargs.get('key', None)
     data = {}
     headers = []
+    if include:
+        text_data = _get_include_data(text_data, include)
     for row in reader(iter(text_data.splitlines())):
         if not row:
             continue
